# Name: example_lenstest.tcl
#
# This script takes a series of photos all with the same light
# exposure but with different combinations of aperture and
# shutter speed. It uses the initial aperture of the camera as
# a starting point, and then takes a series of photos at
# decreasing apertures sizes. Each time, the shutter speed is
# also adjusted so that the light exposure is the same for
# each photo.
#
# THIS SCRIPT REQUIRES THE CAMERA TO BE IN MANUAL MODE

# TclParameter tolerance 10.0 Exposure tolerance

# Remember the initial aperture and shutter speed
set originalAv [SmartShooter Get Aperture]
set originalTv [SmartShooter Get ShutterSpeed]

# Query the valid range of apertures and shutter speeds
set AvRange [SmartShooter GetList Aperture]
set TvRange [SmartShooter GetList ShutterSpeed]

# Give a rough estimate of the
# light exposure with these settings
set originalExp [expr 1.0 / ($originalAv * $originalAv) * $originalTv]

# Iterate over each valid aperture
foreach Av $AvRange {

	# Check this aperture is smaller than
	# or equal to the starting aperture
	if { [expr $originalAv <= $Av] } {
	
		# Iterate over each shutter speed
		foreach Tv $TvRange {

			# Check Tv is a valid numerical expression
			# and not something like "Bulb"
			if { [catch { expr 1.0 * $Tv }] == 0 } {

				# Make another estimate of the light exposure
				# with this combinaion of settings
				set exp [expr 1.0 / ($Av * $Av) * $Tv]
							
				# Check this is within range of the
				# original light exposure
				if { [expr abs(1.0 - ($originalExp / $exp)) <= ($tolerance / 100.0)] } {
				
					puts "Taking photo with Av = $Av and Tv = $Tv"

					SmartShooter Set Aperture $Av
					SmartShooter Set ShutterSpeed $Tv
					SmartShooter TakePhoto
				}
			}
		}
	}
}

# Restore the original aperture and shutter speed
SmartShooter Set Aperture $originalAv
SmartShooter Set ShutterSpeed $originalTv
