# Name: smartshooter_stub.tcl
#
# This file implements stub functions for the Smart Shooter TCL API.
# The purpose is to allow testing and writing of Smart Shooter scripts
# without the need to run them inside the Smart Shooter application.
#
# To include in your script, add "source smartshooter_stub.tcl" to the
# top of your TCL code.

if { [info procs SmartShooter] == "" } {

set SmartShooterStub_numPhotos 0
set SmartShooterStub_activePhoto 0
set SmartShooterStub_value(Aperture)     "4.5"
set SmartShooterStub_value(ShutterSpeed) "1/100"
set SmartShooterStub_value(Iso)          "100"
set SmartShooterStub_value(Exposure)     "0"
set SmartShooterStub_value(Quality)      "JPEG"
set SmartShooterStub_value(MeteringMode) "Evaluative"
set SmartShooterStub_value(WhiteBalance) "AUTO"
set SmartShooterStub_list(Aperture)     [list "4.5" "5" "5.5" "6"]
set SmartShooterStub_list(ShutterSpeed) [list "1" "1/25" "1/100" "1/1000"]
set SmartShooterStub_list(Iso)          [list "100" "200" "400" "800"]
set SmartShooterStub_list(Exposure)     [list "-2" "-1" "0" "1" "2"]
set SmartShooterStub_list(Quality)      [list "RAW" "JPEG"]
set SmartShooterStub_list(MeteringMode) [list "Spot" "Partial" "Evaluative" "Centre-Weighted"]
set SmartShooterStub_list(WhiteBalance) [list "AUTO" "Daylight" "Cloudy" "Tungsten" "Fluorsecent" "Flash" "Shade"]

proc SmartShooter { args } {

    global SmartShooterStub_numPhotos
    global SmartShooterStub_activePhoto
    global SmartShooterStub_list
    global SmartShooterStub_value

    set result ""
    set argc [llength $args]

    if { $argc > 0 } {

        set arg [lindex $args 0]

        switch -- $arg {
            "TakePhoto" {
                set result 1
                set SmartShooterStub_activePhoto $SmartShooterStub_numPhotos
                incr SmartShooterStub_numPhotos
            }
            "MultiShot" {
                set result 1
                set SmartShooterStub_activePhoto $SmartShooterStub_numPhotos
                incr SmartShooterStub_numPhotos
            }
            "MoveFocus" {
                set result 1
            }
            "AutoFocus" {
                set result 1
            }
            "BulbExposure" {
                set result 1
                set SmartShooterStub_activePhoto $SmartShooterStub_numPhotos
                incr SmartShooterStub_numPhotos
            }
            "Set" {
                set result 0
                if { $argc == 3 } {
                    set property [lindex $args 1]
                    set value [lindex $args 2]
                    if { [info exists SmartShooterStub_list($property)] } {
                        if { [lsearch $args $value] != -1 } {
                            set result 1
                            set SmartShooterStub_value($property) $value
                        }
                    }
                }
            }
            "Get" {
                if { $argc == 2 } {
                    set property [lindex $args 1]
                    if { [info exists SmartShooterStub_list($property)] } {
                        set result $SmartShooterStub_value($property)
                    }
                }
            }
            "GetList" {
                if { $argc == 2 } {
                    set property [lindex $args 1]
                    if { [info exists SmartShooterStub_list($property)] } {
                        set result $SmartShooterStub_list($property)
                    }
                }
            }
            "DetectCameras" {
                set result 1
            }
            "Connect" {
                set result 1
            }
            "Disconnect" {
                set result 1
            }
            "Download" {
                set result 1
            }
            "DownloadAll" {
                set result 1
            }
            "EnableLiveView" {
                set result 1
            }
            "DisableLiveView" {
                set result 1
            }
            "EnableLiveViewRecording" {
                set result 1
            }
            "DisableLiveViewRecording" {
                set result 1
            }
            "GetNumCameras" {
                set result 1
            }
            "GetNumPhotos" {
                set result $SmartShooterStub_numPhotos
            }
            "SetActivePhoto" {
                set result 0
                if { $argc == 2 } {
                    set index [lindex $args 1]
                    if { $index >= 0 && $index < $SmartShooterStub_numPhotos } {
                        set result 1
                        set SmartShooterStub_activePhoto $index
                    }
                }
            }
            "SetActiveCamera" {
                set result 0
                if { $argc == 2 } {
                    set index [lindex $args 1]
                    if { $index == 0 } {
                        set result 1
                    }
                }
            }
            "GetActivePhoto" {
                set result ""
                if { $SmartShooterStub_numPhotos > 0 } {
                    set result $SmartShooterStub_activePhoto
                }
            }
            "GetActiveCamera" {
                set result 0
            }
            "GetPhotoName" {
                set result ""
                if { $SmartShooterStub_numPhotos > 0 } {
                    set result "SSP_[expr $SmartShooterStub_activePhoto + 1].jpg"
                }
            }
            "GetCameraName" {
                set result "TEST Camera"
            }
            "GetCameraMake" {
                set result "TEST"
            }
            "CheckStatus" {
                set result 1
            }
            default {
                puts "Unknown SmartShooter TCL function: $arg"
            }
        }
    }

    puts "STUB: SmartShooter $args = \"$result\""

    return $result
}

}

